/************************************************************************/
/*		aPCI-R47 Device Driver											*
/*																		*/
/*			apci47.h	-	Win32 interface definition					*/
/************************************************************************/

#if !defined( APCI47_H )
#define	APCI47_H

#ifdef	__cplusplus
extern	"C" {
#endif

/*==================*/
/*	Error Code		*/
/*==================*/
#define	APCI47_SUCCESS				0	/* Successfully proccessed */
#define	APCI47_ERR_SYSTEM			1	/* Call GetLastError() */
#define	APCI47_ERR_NO_DEVICE		2	/* No card */
#define	APCI47_ERR_IN_USE			3	/* Device is in use */
#define	APCI47_ERR_INVALID_SLOT		4	/* Invalid slot number */
#define	APCI47_ERR_RESOURCE			5	/* Resource exhaustion */
#define	APCI47_ERR_INVALID_PORT		6	/* Invalid port */
#define	APCI47_ERR_INVALID_ARGUMENT	7	/* Invalid argument */
#define	APCI47_ERR_NO_CREATE		8	/* No created device */

/*==========================================*/
/*	aPCI-R47 card's relative port address	*/
/*==========================================*/
#define	APCI47_PORT_1	0
#define	APCI47_PORT_2	1

/*==================*/
/*	Miscellaneous	*/
/*==================*/
#define	APCI47_MAX_SLOTS	16			/* Maximum number of slots */
#define APCI47_MAX_PORTS	2			/* Maximum number of user ports */

										/* default search */
#define	APCI47_SLOT_AUTO		( ( WORD ) ~0U )

/*==============*/
/*	Device ID	*/
/*==============*/
#define	APCI47_BOARD_ID		0x9047		/* pci bus device id */
#define	APCI47_VENDOR_ID	0x136c		/* pci bus vendor id */
										/* our device id */
#define	APCI47_DEVICE_ID	( ( DWORD )APCI47_BOARD_ID\
							| ( ( DWORD )APCI47_VENDOR_ID << 16 ) )

/*==================================*/
/*	Resource infomation structure	*/
/*==================================*/
#define	APCI47_MAX_MEM		9			/* number of memory windows */
#define	APCI47_MAX_IO		20			/* number of i/o windows */
#define	APCI47_MAX_IRQ		7			/* number of irqs */
#define	APCI47_MAX_DMA		7			/* number of dmas */

typedef	struct	_APCI47RESOURCE {
	DWORD	dwNumMemWindows;					/* Not used */
	DWORD	dwMemBase		[APCI47_MAX_MEM];	/* Not used */
	DWORD	dwMemLength		[APCI47_MAX_MEM];	/* Not used */
	DWORD	dwMemAttrib		[APCI47_MAX_MEM];	/* Not used */
	DWORD	dwNumIOPorts;						/* Num IO ports */
	DWORD	dwIOPortBase	[APCI47_MAX_IO];	/* I/O port base */
	DWORD	dwIOPortLength	[APCI47_MAX_IO];	/* I/O port length */
	DWORD	dwNumIRQs;							/* Not used */
	DWORD	dwIRQRegisters	[APCI47_MAX_IRQ];	/* Not used */
	DWORD	dwIRQAttrib		[APCI47_MAX_IRQ];	/* Not used */
	DWORD	dwNumDMAs;							/* Not used */
	DWORD	dwDMALst		[APCI47_MAX_DMA];	/* Not used */
	DWORD	dwDMAAttrib		[APCI47_MAX_DMA];	/* Not used */
	DWORD	dwReserved1		[3];				/* Not used */
} APCI47RESOURCE, *PAPCI47R;

#if !defined( APCI47_DRIVER )
#define	APCI47_API

#if !defined( APCI47_DLL )
	#define APCI47LIB_API	extern __declspec( dllimport )
#else
	#define APCI47LIB_API	extern __declspec( dllexport )
#endif

#ifdef _BORLANDC_
	#define EXPVAR			__pascal
#else
	#define	EXPVAR
#endif

/*==================*/
/*	API Functions	*/
/*==================*/

APCI47LIB_API BOOL	WINAPI	Apci47GetVersion( PDWORD pdwDllVersion, PDWORD pdwDriverVersion );
APCI47LIB_API BOOL	WINAPI	Apci47Create( PWORD pwLogSlot );
APCI47LIB_API BOOL	WINAPI	Apci47Close( WORD wLogSlot );
APCI47LIB_API BOOL	WINAPI	Apci47GetResource( WORD wLogSlot, PAPCI47R pres );
APCI47LIB_API BOOL	WINAPI	Apci47GetSwitchValue( WORD wLogSlot, PDWORD pdwSwitchValue );
APCI47LIB_API BOOL	WINAPI	Apci47InPort( WORD wLogSlot, DWORD dwLogPort, PBYTE pbInValue );
APCI47LIB_API BOOL	WINAPI	Apci47OutPort( WORD wLogSlot, DWORD dwLogPort, BYTE bOutValue );
APCI47LIB_API DWORD	WINAPI	Apci47GetLastError( WORD wLogSlot );

#endif	/* #if !defined( APCI47_DRIVER ) */

#ifdef	__cplusplus
}
#endif

#endif	/* #if !defined( APCI47_H ) */

/**/